@@ -21,9 +21,6 @@ def escape_item(val, charset):
         return escape_sequence(val, charset)
     if type(val) is dict:
         return escape_dict(val, charset)
-    if PYTHON3 and isinstance(val, bytes):
-        # deal with py3k bytes
-        val = val.decode(charset)
     encoder = encoders[type(val)]
     val = encoder(val)
     if type(val) is str:
@@ -64,6 +61,9 @@ def escape_string(value):
     return ("'%s'" % ESCAPE_REGEX.sub(
             lambda match: ESCAPE_MAP.get(match.group(0)), value))
 
+def escape_bytes(value):
+    return '0x' + ''.join([('0'+hex(c)[2:])[-2:] for c in value])
+
 def escape_unicode(value):
     return escape_string(value)
 
@@ -266,6 +266,9 @@ def convert_bit(connection, field, b):
     # so we shouldn't either
     return b
 
+def convert_blob(connection, field, data):
+    return convert_characters(connection, field, data)
+
 def convert_characters(connection, field, data):
     field_charset = charset_by_id(field.charsetnr).name
     if field.flags & FLAG.SET:
@@ -316,7 +319,10 @@ encoders = {
         datetime.time : escape_time,
         time.struct_time : escape_struct_time,
         }
-if not PYTHON3:
+
+if PYTHON3:
+    encoders[bytes] = escape_bytes
+else:
     encoders[unicode] = escape_unicode
     encoders[long] = escape_long
 
@@ -339,17 +345,13 @@ decoders = {
         FIELD_TYPE.TIME: convert_timedelta,
         FIELD_TYPE.DATE: convert_date,
         FIELD_TYPE.SET: convert_set,
-        FIELD_TYPE.BLOB: convert_characters,
-        FIELD_TYPE.TINY_BLOB: convert_characters,
-        FIELD_TYPE.MEDIUM_BLOB: convert_characters,
-        FIELD_TYPE.LONG_BLOB: convert_characters,
+        FIELD_TYPE.BLOB: convert_blob,
+        FIELD_TYPE.TINY_BLOB: convert_blob,
+        FIELD_TYPE.MEDIUM_BLOB: convert_blob,
+        FIELD_TYPE.LONG_BLOB: convert_blob,
         FIELD_TYPE.STRING: convert_characters,
         FIELD_TYPE.VAR_STRING: convert_characters,
         FIELD_TYPE.VARCHAR: convert_characters,
-        #FIELD_TYPE.BLOB: str,
-        #FIELD_TYPE.STRING: str,
-        #FIELD_TYPE.VAR_STRING: str,
-        #FIELD_TYPE.VARCHAR: str
         }
 conversions = decoders  # for MySQLdb compatibility
 
